@@ -25,23 +25,23 @@ class CreateParameter(
     pass
 
 
-class FullUpdateBody(MaxUses):
+class FullDataUpdateBody(MaxUses):
     pass
 
 
-class FullUpdateParameter(
-    FullUpdateBody,
+class FullDataUpdateParameter(
+    FullDataUpdateBody,
     IdentifierTypeValueMixin[IdentifierType, IdentifierValueType],
 ):
     pass
 
 
-class PartialUpdateBody(OptionalMaxUses):
+class PartialDataUpdateBody(OptionalMaxUses):
     pass
 
 
-class PartialUpdateParameter(
-    PartialUpdateBody,
+class PartialDataUpdateParameter(
+    PartialDataUpdateBody,
     IdentifierTypeValueMixin[IdentifierType, IdentifierValueType],
 ):
     pass
